#
# spec file for package xmobar
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name xmobar
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           %{pkg_name}
Version:        0.50
Release:        1.2
Summary:        A Minimalistic Text Based Status Bar
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-X11-devel
BuildRequires:  ghc-X11-prof
BuildRequires:  ghc-X11-xft-devel
BuildRequires:  ghc-X11-xft-prof
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-prof
BuildRequires:  ghc-alsa-core-devel
BuildRequires:  ghc-alsa-core-prof
BuildRequires:  ghc-alsa-mixer-devel
BuildRequires:  ghc-alsa-mixer-prof
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-async-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-cairo-devel
BuildRequires:  ghc-cairo-prof
BuildRequires:  ghc-colour-devel
BuildRequires:  ghc-colour-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-dbus-devel
BuildRequires:  ghc-dbus-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-extensible-exceptions-devel
BuildRequires:  ghc-extensible-exceptions-prof
BuildRequires:  ghc-extra-devel
BuildRequires:  ghc-extra-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-hinotify-devel
BuildRequires:  ghc-hinotify-prof
BuildRequires:  ghc-http-client-tls-devel
BuildRequires:  ghc-http-client-tls-prof
BuildRequires:  ghc-http-conduit-devel
BuildRequires:  ghc-http-conduit-prof
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-http-types-prof
BuildRequires:  ghc-iwlib-devel
BuildRequires:  ghc-iwlib-prof
BuildRequires:  ghc-libmpd-devel
BuildRequires:  ghc-libmpd-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-netlink-devel
BuildRequires:  ghc-netlink-prof
BuildRequires:  ghc-old-locale-devel
BuildRequires:  ghc-old-locale-prof
BuildRequires:  ghc-pango-devel
BuildRequires:  ghc-pango-prof
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-parsec-numbers-devel
BuildRequires:  ghc-parsec-numbers-prof
BuildRequires:  ghc-parsec-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-regex-compat-devel
BuildRequires:  ghc-regex-compat-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-stm-prof
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-prof
BuildRequires:  ghc-timezone-olson-devel
BuildRequires:  ghc-timezone-olson-prof
BuildRequires:  ghc-timezone-series-devel
BuildRequires:  ghc-timezone-series-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
BuildRequires:  ghc-utf8-string-devel
BuildRequires:  ghc-utf8-string-prof
BuildRequires:  libXpm-devel
BuildRequires:  libXrandr-devel
BuildRequires:  libXrender-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-temporary-prof
%endif

%description
Xmobar is a minimalistic text based status bar.

Inspired by the Ion3 status bar, it supports similar features, like dynamic
color management, output templates, and extensibility through plugins.

%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires:       libXrandr-devel
Requires:       libXrender-devel
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup

%build
%define cabal_configure_options -f+all_extensions
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%license license
%doc changelog.md doc readme.org
%{_bindir}/%{name}

%files -n ghc-%{name} -f ghc-%{name}.files
%license license

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc changelog.md doc readme.org

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license license

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Wed Jun  4 2025 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.50.
  [#]# Version 0.50 (June, 2025)
  - New plugins: `PacmanUpdates` (thanks, Alexander)
  - `ArchUpdates` deprecated in favor of `PacmanUpdates`
  - a deprecation notice will be shown to users of that plugin in the bar in
    the zero updates case
  - `Accordion`: new constructor to allow short version to have plugins too
  - `Swap`: update for FreeBSD 15
  - `MPD` compiled again by default with `all_extensions`.
- Drop obsolete "re-enable-support-for-libmpd.patch".
* Tue Apr  1 2025 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.49.
  [#]# Version 0.49 (April, 2025)
  - New plugins: `ArchUpdates` and `Accordion` (thanks, Enrico Maria)
  - New template variable `weatherS` for `WeatherX`.
  - New Nix flake (thanks, refaelsh)
  - `MPRIS`: Fix for duration reported by Spotify (thanks, Claudio)
  - Base dep up to 4.20 (thanks, Alexander)
* Mon Dec 16 2024 Peter Simons <psimons@suse.com>
- Re-generate spec file with a recent versions of Cabal.
* Tue May  7 2024 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.48.1.
  [#]# Version 0.48.1 (May, 2024)
  - Removing for now mouse support for `Kbd`, which can be recovered by
    interested users using regular actions (see issue #703 for further details).
* Mon Apr  1 2024 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.48.
  [#]# Version 0.48 (April, 2024)
  - The `Kbd` monitor is now clickable (thanks, Enrico Maria)
  - Fix zombie processes left by `<action>` tag and low battery action (thanks,
    Ulrik)
  - Fix plugins such as `Alsa` and `Com` not working when configuration is
    recompiled (#657, ditto)
  - New `Lock'` monitor with configurable labels (thanks, Enrico Maria)
  [#]# Version 0.47.4 (March, 2024)
  - Bug fixes (launching processes from self-compiled instances)
* Sun Mar  3 2024 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.47.4.
  Upstream has not updated the file "changelog.md" since the last
  release.
* Wed Feb  7 2024 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.47.3.
  [#]# Version 0.47.3 (February, 2024)
  - New flag `with_shared` to use xmobar with dynamic linking (see PR #690)
  - Fix for actions invoked from recompiled xmobar instances (issue #688)
  - Maximum base version bumped to 4.20
* Mon Nov 13 2023 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.47.2.
  - Compatibility with GHC 9.6
- Apply "re-enable-support-for-libmpd.patch" to enable support for
  libmpd. Upstream disabled this feature becase they can't build
  libmpd, but we can.
* Sat Sep  2 2023 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.47.1.
  - Allow compilation with libmpd even with GHC > 9.4, by
    requesting it explicitly with `with_mpd`. See #667 for further
    details.
  - Fix: center middle section for templates of the for }M{
  - Documentation fixes and improvements
  - Better error handling in network connections
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Thu Jan  5 2023 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.46.
  - New bar position specifiers TopHM, BottomHM.
  - New configuration option, `dpi`, to set the font scaling factor.
  - Fixes and extensions for section aligment behaviour (#650, #655).
  - Fix: honour fc/bg specs for icons (#663).
* Sun Oct 16 2022 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.45.
  - New cairo/pango font drawing backend, substituting the direct
    X11/Xft one.
* Wed Aug 10 2022 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.44.2.
  - Documentation improvements.
  - Missing doc files and xmobar.el added to distribution.
* Mon Jul 18 2022 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.44.1.
  - Repository moved to Codeberg.  No code changes.
* Fri Jul  8 2022 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.44.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/xmobar-0.44/src/changelog.md
* Wed May 11 2022 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.43.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/xmobar-0.43/src/changelog.md
* Tue Mar  1 2022 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.42.
  _New features_
  - New text mode (thanks to Pavel Kagulin, see issue #601), with
    output formats compatible with color terminals and pango.
  - New text mode with format following swaybar-protocol, supporting
    colors, faces, boxes and actions.
  _Bug fixes_
  - Fix for bottom placement (#608)
  - Fix for memory leak during X drawing (#609)
* Sat Jan  1 2022 Peter Simons <psimons@suse.com>
- Update xmobar to version 0.41.
  [#]# Version 0.41 (January, 2022)
  _New features_
  - Disk monitors for FreeBSD (Michal Zielonka).
  - Improvements to signal handling when using xmobar as a library (John Soo).
* Sat Nov  6 2021 psimons@suse.com
- Update xmobar to version 0.40.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/xmobar-0.40/src/changelog.md
* Fri Aug 13 2021 psimons@suse.com
- Update xmobar to version 0.39.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/xmobar-0.39/src/changelog.md
* Wed May 19 2021 psimons@suse.com
- Update xmobar to version 0.38.
  [#]# Version 0.38 (May, 2021)
  _Bug fixes_
  - Fix off-by-one in strut calculation for `Static` position which reserved
    space for the panel than necessary and caused issues in some multi-head
    setups (fixes #530).
  - Revert the double-UTF-8 encoding workarounds of 0.36 (#482), as they're no
    longer necessary with xmonad-contrib master, and aren't needed with any
    released version of xmonad-contrib either.
  - Fix slow reactions to SIGUSR1/2 signals (reposition, change screen).
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Nov 30 2020 psimons@suse.com
- Update xmobar to version 0.37.
  [#]# Version 0.37 (November, 2020)
  _New features_
  - New command line option `--add-font` (Ivan Brennan)
  - New monitor `MPDX` that extends `MPD` with the ability of having a
    custom alias.  Useful for connecting with multiple servers.
  - New plugin `NotmuchMail` to monitor mail indexed by `notmuch`.
  _Bug fixes_
  - Fix date plugin not picking up DST and timezone changes (refresh
    timezone once a minute to preserve the optimized performace of 0.34).
* Sun Aug 23 2020 psimons@suse.com
- Update xmobar to version 0.36.
  [#]# Version 0.36 (August, 2020)
  _New features_
  - Monitor progress bars: a value of 0 for `-W` denotes an index in
    the `-f` string, similar to icon patterns but using characters.
  - New tag `<box>` to add borders around text (Unoqwy).
  - `fc` color background now accepts an offset (Unoqwy).
  _Bug fixes_
  - Documentation fixes (Tomáš Janoušek)
  - Don't get confused by empty configuration dirs (fixes #412)
  - Xft rendering: Avoid encoding to UTF8 on all scenarios. This
    causes issue to StdinReader monitor when the handle wasn't binary.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Sat Jun 27 2020 psimons@suse.com
- Update xmobar to version 0.35.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/xmobar-0.35.1/src/changelog.md
* Sun Jun 14 2020 psimons@suse.com
- Update xmobar to version 0.34.
  [#]# Version 0.34 (June, 2020)
  _New features_
  - New plugin `HandleReader` for reading data from a Haskell `Handle`. This is
    useful if you are running xmobar from within a Haskell program.
  - Build with ghc 8.10 allowed.
  - Optimize date plugin by avoiding calling getTimeZone for each of
    the time the date has to be updated. Instead, it's computed once
    at the start and re-used for each invocation.
  - Optimize Weather and UVMeter plugin by using global Manager instead of
    creating for each http request when useManager is explicitly configured as False.
* Fri May 29 2020 Peter Trommler <ptrommler@icloud.com>
- increase disk space on ppc64, ppc64le
* Thu May  7 2020 Peter Simons <psimons@suse.com>
- Drop obsolete %%setup hack to work around a missing Setup.hs file.
  New ghc-rpm-macros do this automatically.
- Tweak dependency information to fix building with ghc-8.10.x.
* Thu Feb 27 2020 psimons@suse.com
- Update xmobar to version 0.33.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/xmobar-0.33/src/changelog.md
* Mon Dec  9 2019 psimons@suse.com
- Update xmobar to version 0.32.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/xmobar-0.32/src/changelog.md
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Oct 12 2019 psimons@suse.com
- Update xmobar to version 0.31.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/xmobar-0.31/src/changelog.md
* Fri Aug 23 2019 psimons@suse.com
- Update xmobar to version 0.30.
  [#]# Version 0.30 (August, 2019)
  _New features_
  - New monitor `MultiCoreTemp`, thanks to Felix Springer.
  - `DiskIO`: Additional template variables for absolute number of
    bytes rather than speeds (see [issue #390].
  - `WeatherX`: An extension to the `Weather` monitor allowing the
    spefication of custom strings or icons for sky conditions.
  - The battery monitors accept the new arguments `-a` and `-A` to
    specify a system command executed if battery left goes beyond a
    given threshold.
  [issue #390]: https://github.com/jaor/xmobar/issues/390
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Build xmobar with 'datezone' extension enabled.
* Sun Mar 17 2019 psimons@suse.com
- Update xmobar to version 0.29.5.
  [#]# Version 0.29.5 (March, 2019)
  _Bug fixes_
  - Honour command line flags when starting xmobar without any
    configuration file (issue #375).
  - `Alsa` plugin: restart `alsactl` if it quits, e.g. because of a
    sleep/awake cycle (issue #376).
  - `Weather` using the new HTTPS URL, which requires http-conduit as
    a dependency (issue #378).
  - `MarqueePipeReader` exported at the API level (issue #381).
* Tue Dec 25 2018 psimons@suse.com
- Update xmobar to version 0.29.4.
  [#]# Version 0.29.4 (December, 2018)
  Upgrade to alsa-mixer 0.3.0.  See issues #372 and #373.
* Tue Dec 11 2018 psimons@suse.com
- Update xmobar to version 0.29.3.
  [#]# Version 0.29.3 (December, 2018)
  _Bug fixes_
  - Upper bound for alsa_mixer (see [issue #372])
  [issue #372]: https://github.com/jaor/xmobar/issues/372
* Sun Dec  9 2018 psimons@suse.com
- Update xmobar to version 0.29.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/xmobar-0.29.2/src/changelog.md
* Thu Dec  6 2018 psimons@suse.com
- Update xmobar to version 0.29.1.
  [#]# Version 0.29.1 (December, 2018)
  _Bug fixes_
  - Honour command line flags (fixes [issue #370])
  - Expose Cmd and CmdX in Xmobar interface
  [issue #370]: https://github.com/jaor/xmobar/issues/370
* Sat Dec  1 2018 psimons@suse.com
- Update xmobar to version 0.29.
  - New `Alsa` monitor for volume display that doesn't use polling, by
    Daniel Schüssler.
  - `ThermalZone` retries reading missing files, thanks to Reed Koser.
  - `TopProc` ignores kernel threads (see also [issue #369]).
  - `Wireless` simple autodetection of wirless interface name (if set
    to "").
  - Experimental support for using xmobar as a library, so that
    configurations are in fact Haskell programs a la Xmonad (beta
    stage, with help from Pavan Rikhi). Traditional config files are
    still (and will continue to be) supported.
  - Correctly parsing configuration options `mwClass` and `wmName`.
  [issue #369]: https://github.com/jaor/xmobar/issues/369
* Sun Oct  7 2018 psimons@suse.com
- Update xmobar to version 0.28.1.
  - Dependencies updated to work with GHC 8.6, avoiding [issue #354].
  [issue #354]: https://github.com/jaor/xmobar/issues/354
* Wed Aug 22 2018 psimons@suse.com
- Update xmobar to version 0.28.
  [#]# Version 0.28
  _New features_
  - New `ComX`, which runs a command with custom exit error message.
  _Bug fixes_
  - hinotify version upgraded ([issue #356])
  [issue #356]: https://github.com/jaor/xmobar/issues/356
* Tue Jul 31 2018 psimons@suse.com
- Add xmobar at version 0.27.
